@@ -16,24 +16,16 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GlobalHistory.h,v 1.6 2004/04/29 10:41:10 marco Exp $
+ *  $Id: GlobalHistory.h,v 1.8 2004/08/10 08:50:09 chpe Exp $
  */
 
 #ifndef EPHY_GLOBAL_HISTORY_H
 #define EPHY_GLOBAL_HISTORY_H
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #include "ephy-history.h"
 
 #include <nsIBrowserHistory.h>
-#if MOZILLA_SNAPSHOT > 13
 #include <nsIGlobalHistory2.h>
-#else
-#include <nsIGlobalHistory.h>
-#endif
 
 #define EPHY_GLOBALHISTORY_CLASSNAME	"Epiphany Global History Implementation"
 
@@ -44,22 +36,14 @@
 	{ 0xb7, 0x9e, 0xf7, 0xaa, 0x49, 0xeb, 0x6a, 0x15}	\
 }
 
-class MozGlobalHistory:
-#if MOZILLA_SNAPSHOT <= 13
-			public nsIGlobalHistory,
-#endif
-			public nsIBrowserHistory
+class MozGlobalHistory: public nsIBrowserHistory
 {
 	public:
 		MozGlobalHistory ();
 		virtual ~MozGlobalHistory();
 
 		NS_DECL_ISUPPORTS
-#if MOZILLA_SNAPSHOT > 13
 		NS_DECL_NSIGLOBALHISTORY2
-#else
-		NS_DECL_NSIGLOBALHISTORY
-#endif
 		NS_DECL_NSIBROWSERHISTORY
 
 	private:
