@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-notifiers.cpp,v 1.51.4.2 2004/09/26 16:48:26 chpe Exp $
+ *  $Id: mozilla-notifiers.cpp,v 1.51.4.3 2004/09/30 10:16:16 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -105,11 +105,6 @@ mozilla_proxy_mode_notifier (GConfClient *client,
 			     GConfEntry *entry,
 			     EphyEmbedSingle *single);
 static void
-mozilla_proxy_autoconfig_notifier (GConfClient *client,
-			           guint cnxn_id,
-			           GConfEntry *entry,
-			           EphyEmbedSingle *single);
-static void
 mozilla_proxy_mode_notifier (GConfClient *client,
 		             guint cnxn_id,
 		             GConfEntry *entry,
@@ -180,8 +175,6 @@ custom_notifiers [] =
 	  (GConfClientNotifyFunc) mozilla_language_notifier },
 	{ CONF_NETWORK_PROXY_MODE,
 	  (GConfClientNotifyFunc) mozilla_proxy_mode_notifier },
-	{ CONF_NETWORK_PROXY_AUTO_URL,
-	  (GConfClientNotifyFunc) mozilla_proxy_autoconfig_notifier },
 	{ CONF_NETWORK_CACHE_SIZE,
           (GConfClientNotifyFunc) mozilla_cache_size_notifier },
 	{ CONF_SECURITY_COOKIES_ACCEPT,
@@ -355,29 +348,6 @@ mozilla_font_notifier (GConfClient *client,
 	}
 }
 
-static void
-mozilla_proxy_autoconfig_notifier (GConfClient *client,
-		       	           guint cnxn_id,
-		       		   GConfEntry *entry,
-		       		   EphyEmbedSingle *single)
-{
-        nsCOMPtr<nsIProtocolProxyService> pps =
-                do_GetService ("@mozilla.org/network/protocol-proxy-service;1");
-        if (!pps) return;
-
-	char *url = eel_gconf_get_string (entry->key);
-	if (url && url[0] != '\0')
-	{
-#ifdef MOZ_NSIPROTOCOLPROXYSERVICE_NSACSTRING_
-	        pps->ConfigureFromPAC (nsEmbedCString (url));
-#else
-	        pps->ConfigureFromPAC (url);
-#endif
-	}
-
-	g_free (url);
-}
-
 static void
 add_notification_and_notify (GConfClient		*client,
 			     const char 		*key,
