@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-notebook.c,v 1.46 2004/08/26 18:50:46 chpe Exp $
+ *  $Id: ephy-notebook.c,v 1.46.4.2 2004/09/13 10:49:22 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -25,6 +25,7 @@
 #endif
 
 #include "ephy-notebook.h"
+#include "ephy-stock-icons.h"
 #include "eel-gconf-extensions.h"
 #include "ephy-prefs.h"
 #include "ephy-marshal.h"
@@ -38,6 +39,7 @@
 #include "ephy-label.h"
 #include "ephy-spinner.h"
 #include "ephy-string.h"
+#include "ephy-stock-icons.h"
 
 #include <glib-object.h>
 #include <gtk/gtkeventbox.h>
@@ -844,12 +846,10 @@ build_tab_label (EphyNotebook *nb, EphyTab *tab)
 {
 	GtkWidget *window, *hbox, *label_hbox, *label_ebox;
 	GtkWidget *label, *close_button, *image, *spinner, *icon;
-	int h = -1, w = -1;
+	GtkIconSize close_icon_size;
 
 	window = gtk_widget_get_toplevel (GTK_WIDGET (nb));
 
-	gtk_icon_size_lookup (GTK_ICON_SIZE_MENU, &w, &h);
-
 	/* set hbox spacing and label padding (see below) so that there's an
 	 * equal amount of space around the label */
 	hbox = gtk_hbox_new (FALSE, 4);
@@ -865,9 +865,8 @@ build_tab_label (EphyNotebook *nb, EphyTab *tab)
 	close_button = gtk_button_new ();
 	gtk_button_set_relief (GTK_BUTTON (close_button),
 			       GTK_RELIEF_NONE);
-	image = gtk_image_new_from_stock (GTK_STOCK_CLOSE,
-					  GTK_ICON_SIZE_MENU);
-	gtk_widget_set_size_request (close_button, w, h);
+	close_icon_size = gtk_icon_size_from_name (EPHY_ICON_SIZE_TAB_BUTTON);
+	image = gtk_image_new_from_stock (EPHY_STOCK_CLOSE_TAB, close_icon_size);
 	gtk_container_add (GTK_CONTAINER (close_button), image);
 	gtk_box_pack_start (GTK_BOX (hbox), close_button, FALSE, FALSE, 0);
 
