@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: window-commands.c,v 1.129 2004/07/19 08:27:06 marco Exp $
+ *  $Id: window-commands.c,v 1.131.4.2 2004/10/04 22:03:23 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -728,6 +728,11 @@ editor_can_open_uri (char *address)
 		gnome_vfs_uri_unref (uri);
 	}
 
+	if (app)
+	{
+		gnome_vfs_mime_application_free (app);
+	}
+
 	return result;
 }
 
@@ -789,6 +794,8 @@ window_cmd_view_page_source (GtkAction *action,
 	{
 		save_temp_source (embed);
 	}
+
+	g_free (address);
 }
 
 void
@@ -875,6 +882,8 @@ window_cmd_edit_toolbar (GtkAction *action,
         gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (window));
 	gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
 
+	ephy_gui_set_default_window_icon (GTK_WINDOW (dialog));
+
 	editor = egg_toolbar_editor_new (GTK_UI_MANAGER (window->ui_merge), model);
 	egg_toolbar_editor_load_actions (EGG_TOOLBAR_EDITOR (editor),
 					 ephy_file ("epiphany-toolbar.xml"));
@@ -956,7 +965,7 @@ window_cmd_help_about (GtkAction *action,
 	icon_theme = gtk_icon_theme_get_default ();
 	icon_info = gtk_icon_theme_lookup_icon (icon_theme, "web-browser", -1, 0);
 
-	if (icon_info)
+	if (icon_info != NULL)
 	{
 		icon_path = gtk_icon_info_get_filename (icon_info);
 
@@ -964,6 +973,8 @@ window_cmd_help_about (GtkAction *action,
 		{
 			icon = gdk_pixbuf_new_from_file (icon_path, NULL);
 		}
+
+		gtk_icon_info_free (icon_info);
 	}
 	else
 	{
